==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/GetTileImageUriArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GetTileImageUriArgsDescription } from "./GetTileImageUriArgsDescription";
/**
 * @hidden
 */
export let GetTileImageUriArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GetTileImageUriArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GetTileImageUriArgsDescriptionMetadata.a == null) {
                GetTileImageUriArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GetTileImageUriArgsDescriptionMetadata.c(GetTileImageUriArgsDescriptionMetadata.a);
            }
            if (a.j(GetTileImageUriArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GetTileImageUriArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("TileLevel", "Number:int");
            a.item("TilePositionX", "Number:int");
            a.item("TilePositionY", "Number:int");
            a.item("TileImageUri", "String");
        }
        static d(a) {
            GetTileImageUriArgsDescriptionMetadata.b(a);
            a.aa("GetTileImageUriArgs", () => new GetTileImageUriArgsDescription());
            a.z("GetTileImageUriArgs", GetTileImageUriArgsDescriptionMetadata.a);
        }
    }
    GetTileImageUriArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GetTileImageUriArgsDescriptionMetadata, 'GetTileImageUriArgsDescriptionMetadata');
    GetTileImageUriArgsDescriptionMetadata.a = null;
    return GetTileImageUriArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GetTileImageUriArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GetTileImageUriArgsDescription } from "./GetTileImageUriArgsDescription";
/**
 * @hidden
 */
export let GetTileImageUriArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GetTileImageUriArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GetTileImageUriArgsDescriptionMetadata.a == null) {
                GetTileImageUriArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GetTileImageUriArgsDescriptionMetadata.c(GetTileImageUriArgsDescriptionMetadata.a);
            }
            if (a.k(GetTileImageUriArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GetTileImageUriArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("TileLevel", "Number:int");
            a.item("TilePositionX", "Number:int");
            a.item("TilePositionY", "Number:int");
            a.item("TileImageUri", "String");
        }
        static d(a) {
            GetTileImageUriArgsDescriptionMetadata.b(a);
            a.ac("GetTileImageUriArgs", () => new GetTileImageUriArgsDescription());
            a.ab("GetTileImageUriArgs", GetTileImageUriArgsDescriptionMetadata.a);
        }
    }
    GetTileImageUriArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GetTileImageUriArgsDescriptionMetadata, 'GetTileImageUriArgsDescriptionMetadata');
    GetTileImageUriArgsDescriptionMetadata.a = null;
    return GetTileImageUriArgsDescriptionMetadata;
})();
